.. _zyprexa:

.. raw:: html

    <br>
    <center>

zyprexa
=======

.. raw:: html

    </center>
    <br>


4. MOGELIJKE BIJWERKINGEN

Zoals elk geneesmiddel kan dit geneesmiddel bijwerkingen hebben, al krijgt niet iedereen daarmee te
maken.

Informeer uw arts meteen als u één van de volgende verschijnselen heeft:

* ongebruikelijke bewegingen vooral van gezicht en tong (een vaak voorkomende bijwerking die kan
  voorkomen bij 1 op de 10 gebruikers);
* bloedstolsels in de aderen (een soms voorkomende bijwerking die kan voorkomen bij 1 op de 100
  gebruikers), met name in de benen (verschijnselen zijn onder andere zwelling, pijn en roodkleuring
  van het been), die zich door de bloedvaten kunnen verplaatsen naar de longen, waardoor ze pijn op de 
  borst en moeilijkheden bij het ademen kunnen veroorzaken. Als u één van deze verschijnselen
  constateert, win dan onmiddellijk medisch advies in;
* een combinatie van koorts, sneller ademen, zweten, spierstijfheid en sufheid of slaperigheid (hoe vaak
  deze bijwerking voorkomt, is op basis van de beschikbare gegevens niet te berekenen)
  Zeer zelden ernstige allergische reacties zoals DRESS (Drugreactie met eosinofilie en systemische
  symptomen). DRESS begint met griepachtige symptomen en huiduitslag in het gezicht, die zich daarna
  verder over het lichaam verspreidt, hoge temperatuur, vergrote lymfeklieren, verhoogde
  leverenzymwaarden die blijken uit bloedtests en een toename van een soort witte bloedcel (eosinofilie).

Zeer vaak optredende bijwerkingen (kunnen voorkomen bij meer dan 1 op de 10 gebruikers)

* gewichtstoename
* slaperigheid
* verhoogde prolactinespiegels in het bloed

In de vroege stadia van de behandeling kunnen sommige mensen zich duizelig voelen of flauwvallen (met
een trage hartslag), vooral wanneer men overeind komt vanuit een liggende of zittende positie. Dit gaat
gewoonlijk vanzelf over, maar als dit niet het geval is, raadpleeg dan uw arts.

Vaak optredende bijwerkingen (kunnen voorkomen bij maximaal 1op de 10 gebruikers)

* veranderingen in waarden voor sommige bloedcellen en circulerende vetten
* tijdelijke verhogingen van de leverenzymen in het begin van de behandeling
* verhoogde suikerspiegels in bloed en urine
* verhogingen van de spiegels van urinezuur en creatinefosfokinase in het bloed
* sterker hongergevoel
* duizeligheid
* rusteloosheid
* beven
* ongebruikelijke bewegingen (dyskinesie)
* obstipatie (verstopping)
* droge mond
* huiduitslag
* krachtverlies
* hevige vermoeidheid
* vasthouden van vocht met zwelling van handen, enkels of voeten
* koorts
* gewrichtspijn
* seksueel disfunctioneren zoals afgenomen libido bij mannen en vrouwen of erectiestoornis bij mannen

Soms optredende bijwerkingen (kunnen voorkomen bij maximaal 1 op de 100 gebruikers)

* overgevoeligheid (bijvoorbeeld zwelling in de mond en keel, jeuk, huiduitslag)
* diabetes of erger worden van diabetes, soms geassocieerd met ketoacidose (ketonen in het bloed en de
  urine) of coma
* toevallen, gewoonlijk geassocieerd met een voorgeschiedenis van toevallen (epilepsie)
* spierstijfheid of spasmen (met inbegrip van oogbewegingen)
* problemen met praten
* trage hartslag
* gevoeligheid voor zonlicht
* neusbloeding
* opgezwollen buik
* geheugenverlies of vergeetachtigheid
* urine-incontinentie
* niet kunnen plassen
* haaruitval
* afwezigheid of afname van menstruele perioden
* veranderingen in de borsten bij mannen en vrouwen zoals een abnormale productie van melk of
  abnormale groei

Zelden optredende bijwerkingen (kunnen voorkomen bij maximaal 1 op de 1000 gebruikers)

* verlaging van de normale lichaamstemperatuur
* afwijkende hartritmes
* plotselinge onverklaarbare dood
* ontsteking van de alvleesklier die ernstige buikpijn, koorts en ziekte kan veroorzaken
* leveraandoening die tot uiting komt als geel worden van de huid en van de witte gedeelten in de ogen
* spierziekte tot uiting komend als onverklaarbare pijn
* langdurige en/of pijnlijke erectie

Tijdens het gebruik van olanzapine kan zich bij oudere patiënten met dementie een beroerte voordoen,
longontsteking, urine-incontinentie, valincidenten, extreme vermoeidheid, gezichtshallucinaties, stijging
van de lichaamstemperatuur, roodverkleuring van de huid en moeite met lopen. In deze specifieke groep
patiënten hebben zich enkele gevallen van overlijden voorgedaan.

Bij patiënten met de ziekte van Parkinson kan Olanzapine CF de verschijnselen verergeren.
